@@ -145,6 +145,30 @@ class nqdm(tqdm.tqdm):
         self.random = random
     def v(self):
         return self.values
+    def __getitem__(self, subscript):
+        if isinstance(subscript, slice):
+            return self.__getslice__(subscript)
+        else:
+            return self.values[subscript]
+    def __getslice__(self, subscript):
+        start = subscript.start
+        stop = subscript.stop
+        step = subscript.step
+        if start is None:
+            start = 0
+        if stop is None:
+            stop = self.__len__()
+        if step is None:
+            step = 1
+        return nqdm(
+            self.values[start:stop:step], 
+            random=self.random,
+            desc=self.desc,
+            leave=self.leave,
+            colour=self.colour
+        )
+    def __len__(self):
+        return self.total
     def __iter__(self):
         mininterval = self.mininterval
         last_print_t = self.last_print_t
